@@ -18,38 +18,43 @@ OC.L10N.register(
     "You have unarchived the board {board}" : "Du har genskabt tavlen {board}",
     "{user} has unarchived the board {before}" : "{user} har genskabt tavlen {before}",
     "You have created a new list {stack} on board {board}" : "Du har oprettet en ny liste {stack} på tavlen {board}",
-    "{user} has created a new list {stack} on board {board}" : "{user} har oprettet en ny kolonne {stack} på tavlen {board}",
-    "You have renamed list {before} to {stack} on board {board}" : "Du har omdøbt kolonnen {before} til {stack} på tavlen {board}",
-    "{user} has renamed list {before} to {stack} on board {board}" : "{user} har omdøbt kolonnen{before} til {stack} på tavlen {board}",
-    "You have deleted list {stack} on board {board}" : "Du har slettet kolonnen {stack} på tavlen {board}",
-    "{user} has deleted list {stack} on board {board}" : "{user} har slettet kolonnen {stack} på tavlen {board}",
-    "You have created card {card} in list {stack} on board {board}" : "Du har oprettet kortet {card} i kolonnen {stack} på tavlen {board}",
-    "{user} has created card {card} in list {stack} on board {board}" : "{user} har oprettet kortet {card} i kolonnen {stack} på tavlen {board}",
+    "{user} has created a new list {stack} on board {board}" : "{user} har oprettet en ny liste {stack} på tavlen {board}",
+    "You have renamed list {before} to {stack} on board {board}" : "Du har omdøbt liste {before} til {stack} på tavlen {board}",
+    "{user} has renamed list {before} to {stack} on board {board}" : "{user} har omdøbt liste {before} til {stack} på tavlen {board}",
+    "You have deleted list {stack} on board {board}" : "Du har slettet liste {stack} på tavlen {board}",
+    "{user} has deleted list {stack} on board {board}" : "{user} har slettet liste {stack} på tavlen {board}",
+    "You have created card {card} in list {stack} on board {board}" : "Du har oprettet kortet {card} i listen {stack} på tavlen {board}",
+    "{user} has created card {card} in list {stack} on board {board}" : "{user} har oprettet kortet {card} i listen {stack} på tavlen {board}",
     "You have deleted card {card} in list {stack} on board {board}" : "Du har slettet kortet {card} i listen {stack} på tavlen {board}",
     "{user} has deleted card {card} in list {stack} on board {board}" : "{user} har slettet kortet {card} i listen {stack} på tavlen {board}",
     "You have renamed the card {before} to {card}" : "Du har omdøbt kortet {before} til {card}",
     "{user} has renamed the card {before} to {card}" : "{user} har omdøbt kortet {before} til {card}",
-    "Deck" : "Deck",
+    "Deck" : "Opslag",
+    "Changes in the <strong>Deck app</strong>" : "Ændringer i <strong>Opslags app'en</strong>",
     "Upcoming cards" : "Kommende kort",
     "Load more" : "Hent flere",
-    "Personal" : "Personligt",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kortet \"%s\" på \"%s\" er blevet tildelt dig af %s.",
+    "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} har tilknyttet kortet {deck-card} på {deck-board} til dig.",
     "The card \"%s\" on \"%s\" has reached its due date." : "Kortet \"%s\" på \"%s\" har nået sin forfaldsdato.",
+    "The card {deck-card} on {deck-board} has reached its due date." : "Kortet {deck-card} på {deck-board} har nået sin forfaldsdato.",
     "%s has mentioned you in a comment on \"%s\"." : " %s har nævnt dig i en kommentar på \"%s\".",
+    "{user} has mentioned you in a comment on {deck-card}." : "{user} har nævnt dig i en kommentar på {deck-card}.",
     "The board \"%s\" has been shared with you by %s." : "Tavlen \"%s\" er blevet delt med dig af %s.",
+    "{user} has shared {deck-board} with you." : "{user} har delt {deck-board} med dig.",
+    "Deck board" : "Opslagstavle",
+    "Deck boards, cards and comments" : "Opslagstavler, kort og kommentarer",
+    "Create a new deck card" : "Opret et nyt opslagskort",
     "%s on %s" : "%s på %s",
+    "Deck boards and cards" : "Opslagstavler og -kort",
     "No data was provided to create an attachment." : "Ingen data blev givet som kunne vedhæftes",
     "Finished" : "Færdiggjort",
     "To review" : "Til gennemgang",
     "Action needed" : "Handling påkrævet",
     "Later" : "Senere",
     "copy" : "kopiér",
-    "To do" : "To do",
-    "Doing" : "Igang",
+    "To Do" : "To-do liste",
+    "In Progress" : "I gang",
     "Done" : "Afsluttet",
-    "Example Task 3" : "Eksempel opgave 3",
-    "Example Task 2" : "Eksempel opgave 2",
-    "Example Task 1" : "Eksempel opgave 1",
     "The file was uploaded" : "Filen blev uploadet",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Den uploadede fil overstiger upload_max_filesize direktivet i php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uploadede fil overstiger MAX_FILE_SIZE indstilingen, som specificeret i HTML formularen",
@@ -57,28 +62,27 @@ OC.L10N.register(
     "No file was uploaded" : "Ingen fil uploadet",
     "Missing a temporary folder" : "Manglende midlertidig mappe.",
     "Could not write file to disk" : "Kunne ikke gemme filen",
-    "A PHP extension stopped the file upload" : "En PHP udvidelse stoppede fil uploaden.",
-    "No file uploaded or file size exceeds maximum of %s" : "Ingen fil blev uploadet eller fil størrelsen er større end det maksimale: %s.",
+    "A PHP extension stopped the file upload" : "En PHP udvidelse stoppede filupload.",
+    "No file uploaded or file size exceeds maximum of %s" : "Ingen fil blev uploadet eller filstørrelsen er større end maksimum: %s.",
     "Card not found" : "Kort ikke fundet.",
     "Path is already shared with this card" : "Stien er allerede delt med dette kort.",
-    "Invalid date, date format must be YYYY-MM-DD" : "Ikke gyldig dato - dato formatet skal være YYYY-MM-DD",
-    "Personal planning and team project organization" : "Personlig planlægning og organisering af team projekter",
-    "Card details" : "Kort detaljer",
+    "Invalid date, date format must be YYYY-MM-DD" : "Ikke gyldig dato - dato formatet skal være ÅÅÅÅ-MM-DD",
+    "Personal planning and team project organization" : "Personlig planlægning og organisering af teamprojekter",
+    "Card details" : "Kortdetaljer",
     "Add board" : "Tilføj tavle",
-    "Select the board to link to a project" : "Vælg en tavle at linke til et projekt",
-    "Search by board title" : "Søg efter tavle titel",
+    "Select the board to link to a project" : "Vælg tavlen der skal linkes til et projekt",
+    "Search by board title" : "Søg efter tavletitel",
     "Select board" : "Vælg tavle",
-    "Move card to another board" : "Flyt kort til en anden tavle",
-    "Select a board" : "Vælg én tavle",
-    "No lists available" : "Ingen kolonner tilgængelige",
-    "Select a list" : "Vælg en kolonne",
+    "Select a board" : "Vælg en tavle",
+    "No lists available" : "Ingen lister tilgængelige",
+    "Select a list" : "Vælg en liste",
     "Move card" : "Flyt kort",
-    "Cancel" : "Annullér",
     "Select a card" : "Vælg et kort",
-    "Select the card to link to a project" : "Vælg et kort at linke til et projekt",
+    "Cancel" : "Annuller",
+    "Select the card to link to a project" : "Vælg kortet der skal linkes til et projekt",
     "Link to card" : "Link til kort",
     "File already exists" : "Filen findes allerede",
-    "A file with the name {filename} already exists." : "En fil med navnet {filename} already exists.",
+    "A file with the name {filename} already exists." : "En fil med navnet {filename} eksisterer allerede.",
     "Do you want to overwrite it?" : "Vil du overskrive?",
     "Overwrite file" : "Overskriv fil",
     "Keep existing file" : "Behold den eksisterende fil",
@@ -86,16 +90,16 @@ OC.L10N.register(
     "Drop your files to upload" : "Slip dine filer for at uploade",
     "Add card" : "Tilføj kort",
     "Archived cards" : "Arkiverede kort",
-    "Add list" : "Tilføj kolonne",
-    "List name" : "Kolonne navn",
+    "Add list" : "Tilføj liste",
+    "List name" : "Listenavn",
     "Active filters" : "Aktive filtre",
     "Apply filter" : "Aktivér filter",
-    "Filter by tag" : "Filtrer vha. mærkat",
-    "Filter by assigned user" : "Filtrer vha. tildelt bruger",
+    "Filter by tag" : "Filtrer efter Tag",
+    "Filter by assigned user" : "Filtrer efter tildelt bruger",
     "Unassigned" : "Ikke tildelt",
     "Open" : "Åbn",
     "Completed" : "Fuldført",
-    "Filter by due date" : "Filtrer vha. forfaldsdato",
+    "Filter by due date" : "Filtrer efter forfaldsdato",
     "Overdue" : "Overskredet",
     "Next 24 hours" : "De næste 24 timer",
     "Next 7 days" : "De næste 7 dage",
@@ -109,12 +113,12 @@ OC.L10N.register(
     "Details" : "Detaljer",
     "Loading board" : "Indlæser tavle",
     "Board not found" : "Tavle ikke fundet.",
-    "Create a new list to add cards to this board" : "Opret en ny kolonne for at tilføje kort til denne tavle ",
+    "Create a new list to add cards to this board" : "Opret en ny liste for at tilføje kort til denne tavle ",
     "Sharing" : "Deling",
     "Tags" : "Tags",
     "Deleted items" : "Slettede objekter",
     "Activity" : "Aktivitet",
-    "Deleted lists" : "Slettede kolonner",
+    "Deleted lists" : "Slettede lister",
     "Undo" : "Fortryd",
     "Deleted cards" : "Sletttede kort",
     "No participants found" : "Ingen deltagere fundet",
@@ -125,20 +129,20 @@ OC.L10N.register(
     "Can manage" : "Kan administrere",
     "Owner" : "Ejer",
     "Delete" : "Slet",
-    "Failed to create share with {displayName}" : "Oprettelse af delt drev med {displayName} fejlede",
+    "Failed to create share with {displayName}" : "Kunne ikke oprette deling med {displayName}",
     "Transfer" : "Overførsel",
     "Archive all cards" : "Arkivér alle kort",
     "Delete list" : "Slet liste",
-    "Archive all cards in this list" : "Arkivér alle kort i denne kolonne",
+    "Archive all cards in this list" : "Arkivér alle kort på denne liste",
     "Add a new card" : "Tilføj et nyt kort",
-    "Card name" : "Kort navn",
-    "List deleted" : "Kolonne slettet",
+    "Card name" : "Kortnavn",
+    "List deleted" : "Liste slettet",
     "Edit" : "Redigér",
-    "Add a new tag" : "Opret et nyt mærkat",
-    "title and color value must be provided" : "Titel og farve skal angives.",
-    "Board name" : "Tavle navn",
+    "Add a new tag" : "Opret et nyt Tag",
+    "title and color value must be provided" : "Titel- og farveværdi skal angives.",
+    "Board name" : "Tavlenavn",
     "Members" : "Medlemmer",
-    "Assign a user to this card…" : "Tildel en bruger til dette kort",
+    "Assign a user to this card…" : "Tildel en bruger til dette kort...",
     "Upload new files" : "Upload nye filer",
     "Share from Files" : "Del fra Filer",
     "Add this attachment" : "Tilføj denne vedhæftning",
@@ -146,20 +150,21 @@ OC.L10N.register(
     "Download" : "Download",
     "Delete Attachment" : "Slet vedhæftning",
     "Restore Attachment" : "Genskab vedhæftning",
-    "File to share" : "Vælg fil til deling",
+    "File to share" : "Fil til deling",
     "Invalid path selected" : "Ugyldig sti valgt.",
-    "Open in sidebar view" : "Åben i sidekolonne",
+    "Open in sidebar view" : "Åben i sidebjælke visning",
     "Open in bigger view" : "Åben i større visning",
     "Attachments" : "Vedhæftede filer",
     "Comments" : "Kommentarer",
     "Modified" : "Ændret",
     "Created" : "Oprettet",
-    "The title cannot be empty." : "Titlen kan ikke være tom",
+    "The title cannot be empty." : "Titlen må ikke være tom",
     "No comments yet. Begin the discussion!" : "Ingen kommentarer endnu. Begynd diskussionen!",
     "Save" : "Gem",
-    "The comment cannot be empty." : "Kommentaren kan ikke være tom.",
-    "The comment cannot be longer than 1000 characters." : "Kommentaren kan ikke være længere end 1000 tegn.",
-    "In reply to" : "som svar til",
+    "The comment cannot be empty." : "Kommentaren må ikke være tom.",
+    "The comment cannot be longer than 1000 characters." : "Kommentaren må ikke være længere end 1000 tegn.",
+    "In reply to" : "Som svar til",
+    "Cancel reply" : "Annuller svar",
     "Reply" : "Besvar",
     "Update" : "Opdatér",
     "Created:" : "Oprettet:",
@@ -167,26 +172,29 @@ OC.L10N.register(
     "(Unsaved)" : "(Ikke gemt)",
     "(Saving…)" : "(Gemmer...)",
     "Formatting help" : "Hjælp til formatering",
-    "Edit description" : "Redigér beskrivelse",
+    "Edit description" : "Rediger beskrivelse",
     "View description" : "Se beskrivelse",
     "Add Attachment" : "Tilføj vedhæftning",
-    "Write a description …" : "Tilføj en beskrivelse...",
+    "Write a description …" : "Skriv en beskrivelse...",
     "Choose attachment" : "Vælg en vedhæftning",
-    "Set a due date" : "Sæt en forfaldsdato",
+    "Set a due date" : "Angiv en forfaldsdato",
     "Remove due date" : "Fjern forfaldsdato",
     "Mark as done" : "Marker som færdig",
     "Not done" : "Ikke færdig",
-    "Unarchive card" : "Gen-aktivér kort",
+    "Unarchive card" : "Genaktiver kort",
     "Archive card" : "Arkivér kort",
     "Select Date" : "Vælg dato",
-    "Assign a tag to this card…" : "Tilføj et mærkat til dette kort ...",
+    "Assign a tag to this card…" : "Tilføj et Tag til dette kort ...",
     "(group)" : "(gruppe)",
+    "Open link" : "Åben link",
+    "Edit title" : "Rediger titel",
     "Assign to me" : "Tildel til mig",
     "Unassign myself" : "Fjern mig selv",
     "Delete card" : "Slet kort",
     "Card deleted" : "Kort slettet",
     "seconds ago" : "få sekunder siden",
     "Keyboard shortcuts" : "Tastaturgenveje",
+    "Boost your productivity using Deck with keyboard shortcuts." : "Boost din produktivitet ved at anvende opslag med tastaturgenveje.",
     "Keyboard shortcut" : "Tastaturgenvej",
     "Action" : "Handling",
     "Shift" : "Shift",
@@ -194,16 +202,17 @@ OC.L10N.register(
     "Search" : "Søg",
     "All boards" : "Alle tavler",
     "Archived boards" : "Arkiverede lister",
-    "Shared with you" : "Shared with you",
+    "Shared with you" : "Delt med dig",
+    "Deck settings" : "Opslagsindstillinger",
     "Use bigger card view" : "Brug større kort visning",
     "Show boards in calendar/tasks" : "Vis tavler i kalender/opgaver",
     "Cancel edit" : "Annuller redigering",
-    "Board details" : "Liste detaljer",
+    "Board details" : "Tavledetaljer",
     "Edit board" : "Rediger liste",
     "Clone board" : "Klon tavle",
-    "Unarchive board" : "Gen-aktivér tavle",
+    "Unarchive board" : "Genaktiver tavle",
     "Archive board" : "Arkivér tavle",
-    "Turn on due date reminders" : "Aktivér påmindelser om forfaldsdatoer",
+    "Turn on due date reminders" : "Aktiver påmindelser om forfaldsdatoer",
     "Turn off due date reminders" : "Slå påmindelser om forfaldsdatoer fra",
     "Due date reminders" : "Påmindelser om forfaldsdatoer",
     "All cards" : "Alle kort",
@@ -213,12 +222,21 @@ OC.L10N.register(
     "Board {0} deleted" : "Tavle {0} er slettet",
     "Only assigned cards" : "Kun tildelte kort",
     "No reminder" : "Ingen påmindelse",
-    "An error occurred" : "Der var en fejl",
+    "An error occurred" : "Der opstod en fejl",
     "Delete the board?" : "Slet tavlen?",
+    "Clone {boardTitle}" : "Klon {boardTitle}",
+    "Clone cards" : "Klon kort",
+    "Clone assignments" : "Kloningsopgaver",
+    "Clone labels" : "Kloningslabels",
+    "Clone due dates" : "Klon forfaldsdatoer",
+    "Advanced options" : "Avancerede indstillinger",
+    "Clone" : "Klon",
     "Loading filtered view" : "Indlæser filtreret visning",
     "Today" : "I dag",
     "Tomorrow" : "I morgen",
     "No due" : "Ikke forfalden",
+    "No results found" : "Ingen resultater fundet",
+    "Deck board {name}\n* Last modified on {lastMod}" : "Opslagstavle {name}\n* Senest ændret den {lastMod}",
     "Create card" : "Opret kort",
     "Close" : "Luk",
     "No upcoming cards" : "Ingen kommende kort",
@@ -228,13 +246,17 @@ OC.L10N.register(
     "Message from {author} in {conversationName}" : "Besked fra {author} i {conversationName}",
     "Something went wrong" : "Noget gik galt",
     "Failed to upload {name}" : "Kunne ikke uploade {name}",
-    "Maximum file size of {size} exceeded" : "Maksimal fil størrelse {size} overskredet",
-    "Error creating the share" : "Fejl ved skabelse af delt drev",
-    "Share with a Deck card" : "Del med et Deck kort",
-    "Share {file} with a Deck card" : "Del {file} med et Deck kort",
+    "Maximum file size of {size} exceeded" : "Maksimal filstørrelse {size} overskredet",
+    "Error creating the share" : "Fejl ved oprettelse af delt drev",
+    "Share with a Deck card" : "Del med et opslagskort",
+    "Share {file} with a Deck card" : "Del {file} med et opslagskort",
     "Share" : "Del",
-    "Searching for users, groups and circles …" : "Leder efter brugere, grupper og cirkler ...",
-    "(Circle)" : "(Cirkel)",
-    "Assign to users/groups/circles" : "Tildel til brugere/grupper/cirkler"
+    "Personal" : "Personligt",
+    "To do" : "To do",
+    "Doing" : "Igang",
+    "Example Task 3" : "Eksempel opgave 3",
+    "Example Task 2" : "Eksempel opgave 2",
+    "Example Task 1" : "Eksempel opgave 1",
+    "Move card to another board" : "Flyt kort til en anden tavle"
 },
 "nplurals=2; plural=(n != 1);");
