@@ -76,7 +76,6 @@ OC.L10N.register(
     "Cards due tomorrow" : "明日の期限切れのカード",
     "Upcoming cards" : "今後のカード",
     "Load more" : "さらに読み込む",
-    "Personal" : "個人",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "カード \"%s\"(\"%s\"に所属)が%sによってあなたに割り当てられました。",
     "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} さんが、{deck-board} で、あなたにカード「{deck-card}」を割り当てました。",
     "The card \"%s\" on \"%s\" has reached its due date." : "カード \"%s\"(\"%s\"に所属)は期日に達しました。",
@@ -99,12 +98,9 @@ OC.L10N.register(
     "Action needed" : "必要なアクション",
     "Later" : "後",
     "copy" : "コピー",
-    "To do" : "To do",
-    "Doing" : "行うこと",
+    "To Do" : "To Do",
+    "In Progress" : "進行中",
     "Done" : "完了",
-    "Example Task 3" : "タスク3の例",
-    "Example Task 2" : "タスク2の例",
-    "Example Task 1" : "タスク1の例",
     "The file was uploaded" : "ファイルがアップロードされました",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "アップロードされたファイルがphp.iniのupload_max_filesizeディレクティブを超えています",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "アップロードファイルはHTMLフォームで指定された MAX_FILE_SIZE の制限を超えています",
@@ -125,13 +121,12 @@ OC.L10N.register(
     "Select the board to link to a project" : "プロジェクトにリンクするボードを選択",
     "Search by board title" : "ボードのタイトルで検索",
     "Select board" : "ボードを選択",
-    "Move card to another board" : "カードを他のボードに移動",
     "Select a board" : "ボードを選択",
     "No lists available" : "利用可能なリストはありません",
     "Select a list" : "リストを選択",
     "Move card" : "カードの移動",
-    "Cancel" : "キャンセル",
     "Select a card" : "カードを選択",
+    "Cancel" : "キャンセル",
     "Select the card to link to a project" : "プロジェクトにリンクするカードを選択",
     "Link to card" : "カードへリンク",
     "File already exists" : "ファイルはすでに存在します",
@@ -275,6 +270,7 @@ OC.L10N.register(
     "Todo items" : "Todo項目",
     "{count} comments, {unread} unread" : "コメント {count} 件あり、 {unread} 件未読",
     "Edit card title" : "カードタイトルを編集する",
+    "Edit title" : "タイトルを編集",
     "Assign to me" : "自分に割り当てる",
     "Unassign myself" : "自分への割り当てを解除",
     "Mark as not done" : "未完成のマーク",
@@ -336,6 +332,9 @@ OC.L10N.register(
     "An error occurred" : "エラーが発生しました",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "ボード{title}を削除しますか? これにより、アーカイブされたカードを含むこのボードのすべてのデータが削除されます。",
     "Delete the board?" : "ボードを削除しますか？",
+    "Clone cards" : "カードを複製",
+    "Advanced options" : "詳細オプション",
+    "Clone" : "複製",
     "Loading filtered view" : "フィルタされたビューを読み込み中",
     "Today" : "今日",
     "Tomorrow" : "明日",
@@ -375,9 +374,13 @@ OC.L10N.register(
     "Share with a Deck card" : "デッキのカードで共有する",
     "Share {file} with a Deck card" : "{file}をデッキのカードで共有する",
     "Share" : "共有",
-    "Searching for users, groups and circles …" : "ユーザー、グループ、サークルを検索しています…",
-    "(Circle)" : "(サークル)",
-    "Assign to users/groups/circles" : "ユーザー/グループ/サークルに割り当てる",
+    "Personal" : "個人",
+    "To do" : "To do",
+    "Doing" : "行うこと",
+    "Example Task 3" : "タスク3の例",
+    "Example Task 2" : "タスク2の例",
+    "Example Task 1" : "タスク1の例",
+    "Move card to another board" : "カードを他のボードに移動",
     "Filter by completed" : "完成したものをフィルターする"
 },
 "nplurals=1; plural=0;");
