@@ -68,7 +68,6 @@ OC.L10N.register(
     "A <strong>comment</strong> was created on a card" : "Nalogi je dodana nova <strong>opomba</strong>",
     "Upcoming cards" : "Prihajajoče naloge",
     "Load more" : "Naloži več",
-    "Personal" : "Osebno",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Nalogo »%s« na »%s« vam dodeli %s.",
     "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} vam dodeli nalogo »{deck-card}« na »{deck-board}«.",
     "The card \"%s\" on \"%s\" has reached its due date." : "Naloga »%s« na »%s« je dosegla datum preteka.",
@@ -86,12 +85,8 @@ OC.L10N.register(
     "Action needed" : "Čaka na odziv",
     "Later" : "Kasneje",
     "copy" : "kopija",
-    "To do" : "Prihajajoče naloge",
-    "Doing" : "Naloge v teku",
+    "To Do" : "Naloge",
     "Done" : "Končane naloge",
-    "Example Task 3" : "Primer naloge 3",
-    "Example Task 2" : "Primer naloge 2",
-    "Example Task 1" : "Primer naloge 1",
     "The file was uploaded" : "Datoteka je uspešno poslana.",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Poslana datoteka presega določilo največje dovoljene velikosti v datoteki php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Poslana datoteka presega velikost, ki je določena kot omejitev MAX_FILE_SIZE v zapisu HTML.",
@@ -110,13 +105,12 @@ OC.L10N.register(
     "Select the board to link to a project" : "Izberite zbirko za povezavo s projektom",
     "Search by board title" : "Išči po imenu zbirke",
     "Select board" : "Izbor zbirke",
-    "Move card to another board" : "Premakni nalogo v drugo zbirko",
     "Select a board" : "Izbor zbirke",
     "No lists available" : "Ni razpoložljivih seznamov",
     "Select a list" : "Izbor seznama",
     "Move card" : "Premakni nalogo",
-    "Cancel" : "Prekliči",
     "Select a card" : "Izbor naloge",
+    "Cancel" : "Prekliči",
     "Select the card to link to a project" : "Izbor naloge za povezavo do projekta",
     "Link to card" : "Poveži nalogo",
     "File already exists" : "Datoteka s tem imenom že obstaja.",
@@ -243,6 +237,7 @@ OC.L10N.register(
     "Todo items" : "Naloge",
     "{count} comments, {unread} unread" : "{count} sporočil, {unread} neprebranih",
     "Edit card title" : "Uredi naslov naloge",
+    "Edit title" : "Uredi naslov",
     "Assign to me" : "Nalogo dodeli meni",
     "Unassign myself" : "Odstrani me z naloge",
     "Mark as not done" : "Označi kot Ni končano",
@@ -292,6 +287,9 @@ OC.L10N.register(
     "No reminder" : "Ni vpisanih opomnikov",
     "An error occurred" : "Prišlo je do napake.",
     "Delete the board?" : "Ali želite izbrisati zbirko?",
+    "Clone cards" : "Kloniraj nalogo",
+    "Advanced options" : "Napredne možnosti",
+    "Clone" : "Kloniraj",
     "Loading filtered view" : "Poteka nalaganje filtriranega pogleda",
     "Today" : "Danes",
     "Tomorrow" : "Jutri",
@@ -325,8 +323,12 @@ OC.L10N.register(
     "Share with a Deck card" : "Poveži z nalogo Deck",
     "Share {file} with a Deck card" : "Poveži datoteko {file} z nalogo Deck",
     "Share" : "Souporaba",
-    "Searching for users, groups and circles …" : "Iskanje uporabnikov, skupin in krogov ...",
-    "(Circle)" : "(Krog)",
-    "Assign to users/groups/circles" : "Dodeli uporabnikom/skupinam/krogom"
+    "Personal" : "Osebno",
+    "To do" : "Prihajajoče naloge",
+    "Doing" : "Naloge v teku",
+    "Example Task 3" : "Primer naloge 3",
+    "Example Task 2" : "Primer naloge 2",
+    "Example Task 1" : "Primer naloge 1",
+    "Move card to another board" : "Premakni nalogo v drugo zbirko"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
