@@ -1,19 +1,19 @@
 OC.L10N.register(
     "deck",
     {
-    "You have created a new board {board}" : "您创建了一个新面板{board}",
-    "{user} has created a new board {board}" : "{user} 创建了一个新面板{board}",
-    "You have deleted the board {board}" : "您删除了面板{board}",
-    "{user} has deleted the board {board}" : "{user}删除了面板{board}",
-    "You have restored the board {board}" : "您还原了面板{board}",
-    "{user} has restored the board {board}" : "{user}还原了{board}",
-    "You have shared the board {board} with {acl}" : "您已分享{board}给{acl}",
-    "{user} has shared the board {board} with {acl}" : "{user}已使用{acl}分享面板{board}",
-    "You have removed {acl} from the board {board}" : "您从面板{board}中移除了{acl}",
-    "{user} has removed {acl} from the board {board}" : "{user}从面板{board}中移除了{acl} ",
-    "You have renamed the board {before} to {board}" : "您将面板{before}重命名为{board}",
-    "{user} has renamed the board {before} to {board}" : "{user}将面板{before}重命名为{board}",
-    "You have archived the board {board}" : "您已将面板{board}归档",
+    "You have created a new board {board}" : "您创建了新面板 {board}",
+    "{user} has created a new board {board}" : "{user} 创建了新面板 {board}",
+    "You have deleted the board {board}" : "您删除了面板 {board}",
+    "{user} has deleted the board {board}" : "{user} 删除了面板 {board}",
+    "You have restored the board {board}" : "您还原了面板 {board}",
+    "{user} has restored the board {board}" : "{user} 还原了面板 {board}",
+    "You have shared the board {board} with {acl}" : "您已分享面板 {board} 给 {acl}",
+    "{user} has shared the board {board} with {acl}" : "{user}已使用 {acl} 分享了面板 {board}",
+    "You have removed {acl} from the board {board}" : "您从面板 {board} 中移除了 {acl}",
+    "{user} has removed {acl} from the board {board}" : "{user} 从面板 {board} 中移除了 {acl} ",
+    "You have renamed the board {before} to {board}" : "您将面板 {before} 重命名为 {board}",
+    "{user} has renamed the board {before} to {board}" : "{user} 将面板 {before} 重命名为 {board}",
+    "You have archived the board {board}" : "您已将面板 {board} 归档",
     "{user} has archived the board {before}" : "{user}已将面板{before}归档",
     "You have unarchived the board {board}" : "您已将面板{board}取消归档",
     "{user} has unarchived the board {before}" : "{user}已将面板{before}取消归档",
@@ -37,6 +37,10 @@ OC.L10N.register(
     "{user} has archived card {card} in list {stack} on board {board}" : "{user} 已对面板 {board} 上的列表 {stack} 中的卡片 {card} 执行归档",
     "You have unarchived card {card} in list {stack} on board {board}" : "您已对面板 {board} 上的列表 {stack} 中的卡片 {card} 撤销归档",
     "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} 已对面板 {board} 上的列表 {stack} 中的卡片 {card} 撤销归档",
+    "You have marked the card {card} as done in list {stack} on board {board}" : "您已在面板 {board} 上的列表 {stack} 中将卡片 {card} 标记为已完成",
+    "{user} has marked card {card} as done in list {stack} on board {board}" : "{user} 已在面板 {board} 上的列表 {stack} 中将卡片 {card} 标记为已完成",
+    "You have marked the card {card} as undone in list {stack} on board {board}" : "您已在面板 {board} 上的列表 {stack} 中将卡片 {card} 标记为未完成",
+    "{user} has marked the card {card} as undone in list {stack} on board {board}" : "{user} 已在面板 {board} 上的列表 {stack} 中将卡片 {card} 标记为未完成",
     "You have removed the due date of card {card}" : "您移除了卡片 {card} 的截止日期",
     "{user} has removed the due date of card {card}" : "{user} 移除了卡片 {card} 的截止日期",
     "You have set the due date of card {card} to {after}" : "您将卡片 {card} 的截止日期设置为 {after}",
@@ -72,7 +76,7 @@ OC.L10N.register(
     "Cards due tomorrow" : "卡片明天到期",
     "Upcoming cards" : "即将到来的卡片",
     "Load more" : "加载更多",
-    "Personal" : "个人",
+    "Welcome to Nextcloud Deck!" : "欢迎使用 Nextcloud Deck！",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "卡片  \"%s\" （在 \"%s\" 中）已由%s指派给您。",
     "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} 已将卡片 {deck-card}， 其位于 {deck-board} ，分配给了你",
     "The card \"%s\" on \"%s\" has reached its due date." : "卡片 \"%s\" （在 \"%s\" 中）已到期.",
@@ -95,12 +99,16 @@ OC.L10N.register(
     "Action needed" : "需要操作",
     "Later" : "稍后",
     "copy" : "复制",
-    "To do" : "待办",
-    "Doing" : "进行中",
+    "Read more inside" : "阅读更多内容",
+    "Custom lists - click to rename!" : "自定义列表 - 单击以重命名！",
+    "To Do" : "待办",
+    "In Progress" : "进行中",
     "Done" : "完成",
-    "Example Task 3" : "示例任务 3",
-    "Example Task 2" : "示例任务 2",
-    "Example Task 1" : "示例任务 1",
+    "1. Open to learn more about boards and cards" : "1. 打开以了解更多关于面板和卡片的信息",
+    "2. Drag cards left and right, up and down" : "2. 左右上下拖动卡片",
+    "3. Apply rich formatting and link content" : "3. 应用丰富的格式和链接内容",
+    "4. Share, comment and collaborate!" : "4. 分享、评论和协作！",
+    "Create your first card!" : "创建您的第一张卡片！",
     "The file was uploaded" : "文件已上传",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上传文件的大小已超过 php.ini 中 upload_max_filesize 设置的值",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上传的文件长度超出了 HTML 表单中设定的 MAX_FILE_SIZE 上限",
@@ -121,13 +129,14 @@ OC.L10N.register(
     "Select the board to link to a project" : "选择要链接到一个项目的面板",
     "Search by board title" : "通过标题搜索面板",
     "Select board" : "选择面板",
-    "Move card to another board" : "将卡片移到其他面板",
+    "Move/copy card" : "移动/复制卡片",
     "Select a board" : "选择一个面板",
     "No lists available" : "无列表可用",
     "Select a list" : "选择一个列表",
     "Move card" : "移动卡片",
-    "Cancel" : "取消",
+    "Copy card" : "复制卡片",
     "Select a card" : "选择一张卡片",
+    "Cancel" : "取消",
     "Select the card to link to a project" : "选择要链接到一个项目的卡片",
     "Link to card" : "链接到卡片",
     "File already exists" : "文件已存在",
@@ -146,6 +155,8 @@ OC.L10N.register(
     "Filter by tag" : "按标签筛选",
     "Filter by assigned user" : "按指派的用户筛选",
     "Unassigned" : "未指派",
+    "Filter by status" : "按状态筛选",
+    "Open and completed" : "打开并完成",
     "Open" : "打开",
     "Completed" : "已完成",
     "Filter by due date" : "按截止日期筛选",
@@ -175,9 +186,12 @@ OC.L10N.register(
     "Deleted lists" : "已删除的列表",
     "Undo" : "撤消",
     "Deleted cards" : "已删除的卡片",
+    "Share board with a user, group or team …" : "与用户、群组或团队分享面板…",
+    "Searching for users, groups and teams …" : "搜索用户、群组和团队…",
     "No participants found" : "未找到参与者",
     "Board owner" : "面板所有者",
     "(Group)" : "（群组）",
+    "(Team)" : "（团队）",
     "Can edit" : "可以编辑",
     "Can share" : "可以共享",
     "Can manage" : "可以管理",
@@ -199,11 +213,13 @@ OC.L10N.register(
     "Card name" : "卡片名",
     "List deleted" : "列表被删除",
     "Edit" : "编辑",
-    "Add a new tag" : "新增一个标签",
+    "Add a new tag" : "添加新标签",
     "title and color value must be provided" : "必须提供标题和颜色值",
     "Board name" : "面板名称",
     "Members" : "成员",
+    "Assign to users/groups/team" : "分配给用户/群组/团队",
     "Assign a user to this card…" : "为该卡片指派用户…",
+    "Select a user to assign to this card…" : "选择要分配给此卡片的用户…",
     "Upload new files" : "上传新文件",
     "Share from Files" : "从文件共享",
     "Pending share" : "待分享",
@@ -248,18 +264,24 @@ OC.L10N.register(
     "Remove due date" : "移除截止日期",
     "Mark as done" : "标记为已完成",
     "Due at:" : "到期日：",
+    "Not done" : "未完成",
     "Unarchive card" : "撤销对卡片的归档",
     "Archive card" : "归档卡片",
     "Select Date" : "选择日期",
     "Set due date for later today" : "将截止日期设置为今天晚些时候",
     "Set due date for tomorrow" : "设定明天的截止日期",
-    "Assign a tag to this card…" : "为该卡片分配标签…",
-    "Create a new tag:" : "创建一个新标签：",
+    "Set due date for this weekend" : "设置本周末的截止日期",
+    "Set due date for next week" : "设置下周的截止日期",
+    "Assign a tag to this card…" : "为此卡片分配标签…",
+    "Select or create a tag…" : "选择或创建标签…",
+    "Create a new tag:" : "创建新标签：",
     "(group)" : "（组）",
     "Next week – {timeLocale}" : "下周 – {timeLocale}",
     "Todo items" : "待办事项",
     "{count} comments, {unread} unread" : "{count} 条评论，{unread} 未读",
     "Edit card title" : "编辑卡片标题",
+    "Open link" : "打开链接",
+    "Edit title" : "编辑标题",
     "Assign to me" : "指派给我",
     "Unassign myself" : "不再指派给我",
     "Mark as not done" : "标记为未完成",
@@ -267,9 +289,15 @@ OC.L10N.register(
     "Card deleted" : "卡片被删除",
     "seconds ago" : "几秒前",
     "Keyboard shortcuts" : "键盘快捷键",
+    "Boost your productivity using Deck with keyboard shortcuts." : "使用带有键盘快捷键的 Deck 提高您的生产力。",
+    "Board actions" : "面板操作",
     "Keyboard shortcut" : "键盘快捷键",
     "Action" : "操作",
     "Shift" : "Shift",
+    "Scroll" : "滚动",
+    "Scroll sideways" : "侧向滚动",
+    "Navigate between cards" : "在卡片之间导航",
+    "Esc" : "Esc",
     "Close card details" : "关闭卡详细信息",
     "Ctrl" : "Ctrl",
     "Search" : "搜索",
@@ -279,6 +307,7 @@ OC.L10N.register(
     "Card actions" : "卡片操作",
     "The following actions can be triggered on the currently highlighted card" : "可以在当前突出显示的卡上触发以下操作",
     "Enter" : "输入",
+    "Space" : "空间",
     "Open card details" : "打开卡片详细信息",
     "Edit the card title" : "编辑卡片标题",
     "Assign yourself to the current card" : "将自己分配给当前卡片",
@@ -295,6 +324,7 @@ OC.L10N.register(
     "Limit board creation to some groups" : "限制某些组可以创建看板",
     "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "这些组之外的用户将无法创建自己的看板，但仍然可以在与他们共享的看板上工作。",
     "Cancel edit" : "取消编辑",
+    "Save board" : "保存面板",
     "Board details" : "面板详情",
     "Edit board" : "编辑面板",
     "Clone board" : "克隆面板",
@@ -314,6 +344,15 @@ OC.L10N.register(
     "An error occurred" : "发生错误",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "您确定要删除面板 {title} 吗？这将删除该面板的所有数据，包括已归档卡片。",
     "Delete the board?" : "是否删除面板？",
+    "Clone {boardTitle}" : "克隆 {boardTitle}",
+    "Clone cards" : "克隆卡片",
+    "Clone assignments" : "克隆任务",
+    "Clone labels" : "克隆标签",
+    "Clone due dates" : "克隆到期日",
+    "Advanced options" : "高级选项",
+    "Move all cards to the first list" : "将所有卡片移至第一个列表",
+    "Restore archived cards" : "恢复已存档的卡片",
+    "Clone" : "克隆",
     "Loading filtered view" : "正在加载已筛选的视图",
     "Today" : "今天",
     "Tomorrow" : "明天",
@@ -353,8 +392,13 @@ OC.L10N.register(
     "Share with a Deck card" : "分享给一张看板卡片",
     "Share {file} with a Deck card" : "将{file}分享给一张看板卡片",
     "Share" : "分享",
-    "Searching for users, groups and circles …" : "正在搜索用户、群组和圈子 ......",
-    "(Circle)" : "（圈子）",
-    "Assign to users/groups/circles" : "指派给用户/群组/圈子"
+    "Personal" : "个人",
+    "To do" : "待办",
+    "Doing" : "进行中",
+    "Example Task 3" : "示例任务 3",
+    "Example Task 2" : "示例任务 2",
+    "Example Task 1" : "示例任务 1",
+    "Move card to another board" : "将卡片移到其他面板",
+    "Filter by completed" : "按已完成筛选"
 },
 "nplurals=1; plural=0;");
