@@ -76,7 +76,7 @@ OC.L10N.register(
     "Cards due tomorrow" : "於明日到期的卡片",
     "Upcoming cards" : "快將到期的卡片",
     "Load more" : "載入更多",
-    "Personal" : "個人",
+    "Welcome to Nextcloud Deck!" : "歡迎來到 Nextcloud Deck！",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "%s 已將 “%s” 中的卡片 “%s” 指派給您。",
     "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} 已將 {deck-board} 中的卡片 {deck-card} 指派給您。",
     "The card \"%s\" on \"%s\" has reached its due date." : "\"%s\" 中的卡片 \"%s\" 已到期。",
@@ -99,12 +99,16 @@ OC.L10N.register(
     "Action needed" : "需要採取行動",
     "Later" : "稍後處理",
     "copy" : "複製",
-    "To do" : "待辦",
-    "Doing" : "執行中",
+    "Read more inside" : "您可以在裡面深入了解更多",
+    "Custom lists - click to rename!" : "自定義清單 - 點擊以重新命名！",
+    "To Do" : "待辦",
+    "In Progress" : "進行中",
     "Done" : "完成",
-    "Example Task 3" : "示例任務 3",
-    "Example Task 2" : "示例任務 2",
-    "Example Task 1" : "示例任務 1",
+    "1. Open to learn more about boards and cards" : "1. 打開以了解更多有關面板和卡片的信息",
+    "2. Drag cards left and right, up and down" : "2. 拖動卡片向左和向右、向上和向下",
+    "3. Apply rich formatting and link content" : "3. 應用豐富的格式和連結內容",
+    "4. Share, comment and collaborate!" : "4. 分享、評論和協作！",
+    "Create your first card!" : "創建您的第一張卡片！",
     "The file was uploaded" : "檔案已上傳",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 選項的限制",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
@@ -120,17 +124,19 @@ OC.L10N.register(
     "Invalid date, date format must be YYYY-MM-DD" : "無效的日期，需為 YYYY-MM-DD 格式",
     "Personal planning and team project organization" : "個人規劃和團隊項目組織",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck是一種看板式組織工具，旨在針對與Nextcloud集成的團隊進行個人計劃和項目組織。\n\n\n- 📥 添加您的任務到 card 及將之整理好\n- 📄 用 Markdown 寫下額外的註釋分享分享分享\n- 🔖 分配標籤以更好地組織您的工作\n- 👥 與您的團隊、朋友或家人分享\n- 📎 附加檔案並將其嵌入到您的 Markdown 描述中 \n- 💬 使用意見與您的團隊討論\n- ⚡ 在活動流中跟踪更改\n- 🚀 讓您的專案井井有條",
+    "Card details" : "卡片詳情",
     "Add board" : "添加面板",
     "Select the board to link to a project" : "選擇要連結到一個項目的面板",
     "Search by board title" : "通過標題搜索面板",
     "Select board" : "選擇面板",
-    "Move card to another board" : "將卡片移到其他面板",
+    "Move/copy card" : "移動/複製卡片",
     "Select a board" : "選擇一個面板",
     "No lists available" : "無清單可用",
     "Select a list" : "選擇一個列表",
     "Move card" : "移動卡片",
-    "Cancel" : "取消",
+    "Copy card" : "複製卡片",
     "Select a card" : "選擇卡片",
+    "Cancel" : "取消",
     "Select the card to link to a project" : "選擇要連結到一個項目的卡片",
     "Link to card" : "連結到卡片",
     "File already exists" : "檔案已存在",
@@ -274,7 +280,8 @@ OC.L10N.register(
     "Todo items" : "待辦事項",
     "{count} comments, {unread} unread" : "{count} 條評論，{unread} 條未讀",
     "Edit card title" : "編輯卡片標題",
-    "Card details" : "卡片詳情",
+    "Open link" : "打開連結",
+    "Edit title" : "編輯標題",
     "Assign to me" : "指派給我",
     "Unassign myself" : "自己解除指派",
     "Mark as not done" : "標記為未完成",
@@ -316,6 +323,8 @@ OC.L10N.register(
     "Show boards in calendar/tasks" : "在日曆/任務中顯示面板",
     "Limit board creation to some groups" : "限制面板只能由某些群組創建",
     "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "這些群組之外的用戶將無法創建自己的面板，但仍然可以在與他們共享的面板上工作。",
+    "Cancel edit" : "取消編輯",
+    "Save board" : "保存面板",
     "Board details" : "面板詳情",
     "Edit board" : "編輯面板",
     "Clone board" : "複製面板",
@@ -335,13 +344,21 @@ OC.L10N.register(
     "An error occurred" : "發生錯誤",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "你確定你要刪除 {title} 面板嗎？面板內所有數據(包括已封存的卡片)都將因此被刪除。",
     "Delete the board?" : "是否刪除面板？",
+    "Clone {boardTitle}" : "複製 {boardTitle}",
+    "Clone cards" : "複製 cards",
+    "Clone assignments" : "複製任務分配",
+    "Clone labels" : "複製標籤",
+    "Clone due dates" : "複製期日期",
+    "Advanced options" : "進階選項",
+    "Move all cards to the first list" : "將所有卡片移動到第一個清單",
+    "Restore archived cards" : "還原已封存的卡片",
+    "Clone" : "複製",
     "Loading filtered view" : "正在加載已過濾視圖",
     "Today" : "今日",
     "Tomorrow" : "明日",
     "No due" : "沒有到期的",
     "Search for {searchQuery} in all boards" : "在所有面板中搜索 {searchQuery}",
     "No results found" : "未找到結果",
-    "This weekend – {timeLocale}" : "本週末 – {timeLocale}",
     "Deck board {name}\n* Last modified on {lastMod}" : "Deck 面板 {name}\n* 最後修改於  {lastMod}",
     "{stack} in {board}" : "{board} 中的 {stack}",
     "Click to expand description" : "點擊展開描述",
@@ -361,6 +378,7 @@ OC.L10N.register(
     "upcoming cards" : "快將到期的卡片",
     "New card" : "新卡片",
     "Due on {date}" : "於 {date} 到期",
+    "This weekend – {timeLocale}" : "本週末 – {timeLocale}",
     "Tomorrow – {timeLocale}" : "明天 – {timeLocale}",
     "Later today – {timeLocale}" : "今天稍後 – {timeLocale}",
     "Link to a board" : "連結到面板",
@@ -369,23 +387,18 @@ OC.L10N.register(
     "Message from {author} in {conversationName}" : "來自 {conversationName} 中的 {author} 之消息",
     "Something went wrong" : "發生錯誤了",
     "Failed to upload {name}" : "上傳 {name} 失敗",
-    "Maximum file size of {size} exceeded" : "文件大小 {size} 超出最大限制",
+    "Maximum file size of {size} exceeded" : "檔案大小 {size} 超出最大限制",
     "Error creating the share" : "創建分享出錯",
     "Share with a Deck card" : "用一張 Deck 卡片進行分享 ",
     "Share {file} with a Deck card" : "用一張 Deck 卡片分享 {file}",
     "Share" : "分享",
-    "A <strong>card description</strong> inside the Deck app has been changed" : "Deck 應用程式中的 <strong>卡片描述</strong> 已改變",
-    "Timeline" : "時間線",
-    "Share board with a user, group or circle …" : "與一個用戶、群組或圈子分享面板...",
-    "Searching for users, groups and circles …" : "正在搜尋用戶、群組和圈子 ......",
-    "(Circle)" : "（圈子）",
-    "Assign to users/groups/circles" : "指派給用戶/群組/圈子",
-    "Next week" : "下星期",
-    "Next month" : "下個月",
-    "List is empty" : "列表是空的",
-    "Limit deck usage of groups" : "限制群組使用 Deck",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "限制 Deck 將阻止不屬於這些群組的用戶創建自己的面板。用戶仍然可以在與他們的面板上工作。",
-    "Not completed" : "未完成",
+    "Personal" : "個人",
+    "To do" : "待辦",
+    "Doing" : "執行中",
+    "Example Task 3" : "示例任務 3",
+    "Example Task 2" : "示例任務 2",
+    "Example Task 1" : "示例任務 1",
+    "Move card to another board" : "將卡片移到其他面板",
     "Filter by completed" : "按已完成篩選"
 },
 "nplurals=1; plural=0;");
