@@ -1,24 +1,8 @@
 <?php
-/*
- * @copyright Copyright (c) 2020 Julius Härtl <jus@bitgrid.net>
- *
- * @author Julius Härtl <jus@bitgrid.net>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- *
+
+/**
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 declare(strict_types=1);
@@ -86,7 +70,7 @@ class DeckShareProvider implements \OCP\Share\IShareProvider {
 		IL10N $l,
 		ITimeFactory $timeFactory,
 		IMimeTypeLoader $mimeTypeLoader,
-		?string $userId
+		?string $userId,
 	) {
 		$this->dbConnection = $connection;
 		$this->shareManager = $shareManager;
@@ -127,7 +111,7 @@ class DeckShareProvider implements \OCP\Share\IShareProvider {
 		try {
 			$board = $this->boardMapper->find($boardId);
 			$valid = $valid && !$board->getArchived();
-		} catch (DoesNotExistException | MultipleObjectsReturnedException $e) {
+		} catch (DoesNotExistException|MultipleObjectsReturnedException $e) {
 			$valid = false;
 		}
 
@@ -191,7 +175,7 @@ class DeckShareProvider implements \OCP\Share\IShareProvider {
 		string $target,
 		int $permissions,
 		string $token,
-		?\DateTime $expirationDate
+		?\DateTime $expirationDate,
 	): int {
 		$qb = $this->dbConnection->getQueryBuilder();
 		$qb->insert('share')
@@ -848,7 +832,7 @@ class DeckShareProvider implements \OCP\Share\IShareProvider {
 		$pathSections = explode('/', $data['path'], 2);
 		// FIXME: would not detect rare md5'd home storage case properly
 		if ($pathSections[0] !== 'files'
-			&& in_array(explode(':', $data['storage_string_id'], 2)[0], ['home', 'object'])) {
+			&& (strpos($data['storage_string_id'], 'home::') === 0 || strpos($data['storage_string_id'], 'object::user') === 0)) {
 			return false;
 		}
 		return true;
@@ -983,8 +967,8 @@ class DeckShareProvider implements \OCP\Share\IShareProvider {
 	protected function filterSharesOfUser(array $shares): array {
 		// Deck shares when the user has a share exception
 		foreach ($shares as $id => $share) {
-			$type = (int) $share['share_type'];
-			$permissions = (int) $share['permissions'];
+			$type = (int)$share['share_type'];
+			$permissions = (int)$share['permissions'];
 
 			if ($type === self::SHARE_TYPE_DECK_USER) {
 				unset($shares[$share['parent']]);
